==> financial-front-2.0.0.tar.gz: financial-front-2.0.0/app/controllers/account_titles_controller.rb <==
# -*- coding: utf-8 -*-

# Netsphere Financial Front / ネットスフィア経理フロント
# Copyright (C) 2007-2009,2011 HORIKAWA Hisashi. All rights reserved.
#     http://www.nslabs.jp/bside/
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.


require 'validating_base'

class SearchBox < ValidatingBase
  attr_accessor :name
end


# 勘定科目
# 補助コード込みでエントリを作成する。
class AccountTitlesController < ApplicationController
  before_filter :login_required
  
  # GETs should be safe (see http://www.w3.org/2001/tag/doc/whenToUseGet.html)
  verify :method => :post, :only => [ :destroy, :create, :update, :update_addable ],
         :redirect_to => { :action => :list }
  
  def index
  end
  
  def search
    @search = SearchBox.new params[:search]
    if @search.name.to_s.strip == ''
      @search.errors.add 'name', '検索テキストを指定してください。'
      render :action => 'index'
      return
    end

    text = '%' + normalize_kc(@search.name.strip).upcase + '%' # TODO:fixme
    @account_titles = AccountTitle.find :all,
                      :conditions => ['upper(name) LIKE ? OR kana_name LIKE ?',
                                      text, text],
                      :order => 'account_code, suppl_code'
  end


  # 一覧表示
  def list
    @account_titles = AccountTitle.paginate :page => params[:page], :per_page => 25,
                                    :order => 'account_code, suppl_code'
  end

  
  # 購買伝票で使用可能か選ぶ
  def select_addable
    @account_titles = AccountTitle.find(:all,
                 :conditions => 'end_day is NULL',
                 :order => 'account_code, suppl_code')
  end


  # 更新する
  def update_addable
    list = params[:ss]
    AccountTitle.transaction {
      AccountTitle.find(:all).each {|r|
        r.attributes = params[:account_title][r.id.to_s]
        r.save!
      }
    }
    redirect_to :action => 'select_addable'
  end
  
  def show
    @account_title = AccountTitle.find(params[:id])
  end

  def new
    @account_title = AccountTitle.new
    @account_title.kind = 0
  end

  
  # 作成
  def create
    @account_title = AccountTitle.new params[:account_title]
    @account_title.suppl_code = 0 if !@account_title.suppl_code
    @account_title.end_day = nil if !params[:disable]

    if @account_title.save
      flash[:notice] = 'AccountTitle was successfully created.'
      redirect_to :action => 'list'
    else
      render :action => 'new'
    end
  end

  def edit
    @account_title = AccountTitle.find(params[:id])
  end
  
  # 更新
  def update
    @account_title = AccountTitle.find params[:id]
    @account_title.attributes = params[:account_title]
    @account_title.end_day = nil if !params[:disable]
    if @account_title.save
      flash[:notice] = 'AccountTitle was successfully updated.'
      redirect_to :action => 'show', :id => @account_title
    else
      render :action => 'edit'
    end
  end

  def destroy
    AccountTitle.find(params[:id]).destroy
    redirect_to :action => 'list'
  end

  #############################
  # 特殊な勘定科目

  def show_specials
    @global_setting = GlobalSetting.find :first
  end

  def select_specials
    @global_setting = GlobalSetting.find :first
  end


  def update_specials
    @global_setting = GlobalSetting.find :first
    @global_setting.attributes = params[:global_setting]
    @global_setting.save!
    redirect_to :action => "show_specials"
  end
end

==> financial-front-2.99.0.tar.gz: financial-front-2.99.0/app/controllers/account_titles_controller.rb <==
# -*- coding: utf-8 -*-

# Netsphere Financial Front / ネットスフィア経理フロント
# Copyright (C) 2007-2009,2011 HORIKAWA Hisashi. All rights reserved.
#     http://www.nslabs.jp/bside/
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.


require 'validating_base'

class SearchBox < ValidatingBase
  attr_accessor :name
end


# 勘定科目
# 補助コード込みでエントリを作成する。
class AccountTitlesController < ApplicationController
  before_filter :login_required
  
  # GETs should be safe (see http://www.w3.org/2001/tag/doc/whenToUseGet.html)
  verify :method => :post, 
         :only => [ :destroy, :create, :update, :update_addable ],
         :redirect_to => { :action => :list }
  
  def index
  end
  
  def search
    @search = SearchBox.new params[:search]
    if @search.name.to_s.strip == ''
      @search.errors.add 'name', '検索テキストを指定してください。'
      render :action => 'index'
      return
    end

    text = '%' + normalize_kc(@search.name.strip).upcase + '%' # TODO:fixme
    @account_titles = AccountTitle.find :all,
                      :conditions => ['upper(name) LIKE ? OR kana_name LIKE ?',
                                      text, text],
                      :order => 'account_code, suppl_code'
  end


  # 一覧表示
  def list
    @account_titles = AccountTitle.paginate :page => params[:page], 
                                    :per_page => 25,
                                    :order => 'account_code, suppl_code'
  end

  
  # 購買伝票で使用可能か選ぶ
  def select_addable
    @account_titles = AccountTitle.find(:all,
                 :conditions => 'end_day is NULL',
                 :order => 'account_code, suppl_code')
  end


  # 更新する
  def update_addable
    list = params[:ss]
    AccountTitle.transaction {
      AccountTitle.find(:all).each {|r|
        r.attributes = params[:account_title][r.id.to_s]
        r.save!
      }
    }
    redirect_to :action => 'select_addable'
  end
  
  def show
    @account_title = AccountTitle.find(params[:id])
  end

  def new
    @account_title = AccountTitle.new
    @account_title.kind = 0
  end

  
  # 作成
  def create
    @account_title = AccountTitle.new params[:account_title]
    @account_title.suppl_code = 0 if !@account_title.suppl_code
    @account_title.end_day = nil if !params[:disable]

    if @account_title.save
      flash[:notice] = 'AccountTitle was successfully created.'
      redirect_to :action => 'show', :id => @account_title
    else
      render :action => 'new'
    end
  end

  def edit
    @account_title = AccountTitle.find(params[:id])
  end
  
  # 更新
  def update
    @account_title = AccountTitle.find params[:id]
    @account_title.attributes = params[:account_title]
    @account_title.end_day = nil if !params[:disable]
    if @account_title.save
      flash[:notice] = 'AccountTitle was successfully updated.'
      redirect_to :action => 'show', :id => @account_title
    else
      render :action => 'edit'
    end
  end

  def destroy
    AccountTitle.find(params[:id]).destroy
    redirect_to :action => 'list'
  end

  #############################
  # 特殊な勘定科目

  def show_specials
    @global_setting = GlobalSetting.find :first
  end

  def select_specials
    @global_setting = GlobalSetting.find :first
  end


  def update_specials
    @global_setting = GlobalSetting.find :first
    @global_setting.attributes = params[:global_setting]
    @global_setting.save!
    redirect_to :action => "show_specials"
  end
end
